@@ -21,13 +21,13 @@ function(Symbol,from='1970-01-01',to=Sys.Date(),env=parent.frame(),src='yahoo',
   to.d <- as.numeric(strsplit(as.character(to), "-", )[[1]][3])
 
   tmp <- tempfile()
+  on.exit(unlink(tmp))
   download.file(paste(yahoo.URL,Symbol.name, "&a=", 
             from.m, "&b=", sprintf("%.2d", from.d), "&c=", from.y, 
             "&d=", to.m, "&e=", sprintf("%.2d", to.d), "&f=", 
             to.y, "&g=v&y=0&z=30000", 
             sep = ""), destfile = tmp, quiet = !verbose)
   fr <- read.table(tmp, skip=1, fill=TRUE, as.is=TRUE, sep=",")
-  unlink(tmp)
   fr <- fr[fr$V1=="SPLIT",]
 
   if(NROW(fr)==0) {
