@@ -3,6 +3,19 @@
 #  cat("Version 0.3-7, Revision 461\n")
 #  cat("http://www.quantmod.com\n\n")
 #}
+.plotEnv <- new.env()
+.quantmodEnv <- new.env()
+ 
+quantmodenv <- function() as.environment(".quantmodEnv")
+print.quantmodEnv <- function(x, ...) {
+  print("<environment: quantmodEnv>")
+}
+
+.onAttach <- function(libname,pkgname) {
+  packageStartupMessage("Version 0.4-0 included new data defaults. See ?getSymbols.")
+  # --as-cran check is complaining of this, as a NOTE
+  #attach(NULL, name='.quantmodEnv')  
+}
 
 setOldClass("zoo");
 setOldClass("xts");
